@@ -1,7 +1,6 @@
 import pytest
 import os
 import copy
-import ijson
 
 from django.core.serializers.json import Deserializer
 from representatives.models import Representative
@@ -16,7 +15,7 @@ def test_parltrack_import_representatives():
             'representatives_expected.json')
 
     # Disable django auto fields
-    exclude = ('id', '_state', 'created', 'updated')
+    exclude = ('id', '_state', 'created', 'updated', 'fingerprint')
 
     with open(fixture, 'r') as f:
         import_representatives.main(f)
